==> react-7.4.1.tgz: package/es/AlertMeeting/index.js <==
import React from 'react';
import PropTypes from 'prop-types';
import { Avatar, AlertContainer, CompositeAvatar, Button, Icon } from "./..";
/**
 * @category communication
 * @component meeting-alert
 * @variations collab-ui-react
 */

var AlertMeeting = function AlertMeeting(props) {
  var avatar = props.avatar,
      attendees = props.attendees,
      show = props.show,
      onHide = props.onHide,
      onSnooze = props.onSnooze,
      title = props.title,
      message = props.message,
      status = props.status;

  var renderAvatar = function renderAvatar() {
    if (avatar) {
      return avatar;
    } else {
      if (attendees.length >= 2) {
        return React.createElement(CompositeAvatar, null, React.createElement(Avatar, {
          title: attendees[0].title,
          alt: attendees[0].alt,
          src: attendees[0].src
        }), React.createElement(Avatar, {
          title: attendees[1].title,
          alt: attendees[1].alt,
          src: attendees[1].src
        }));
      } else if (attendees.length === 1) {
        return React.createElement(Avatar, {
          title: attendees[0].title,
          alt: attendees[0].alt,
          src: attendees[0].src
        });
      } else {
        throw new Error('MeetingAlert needs at least one attendee to render an avatar.');
      }
    }
  };

  return show && React.createElement(AlertContainer, {
    className: "cui-alert--meeting"
  }, renderAvatar(), React.createElement("div", {
    className: 'cui-alert__content'
  }, React.createElement("div", {
    className: "cui-alert__title",
    title: title
  }, title), React.createElement("div", {
    className: "cui-alert__status"
  }, status), React.createElement("div", {
    className: "cui-alert__message",
    title: message
  }, message)), React.createElement("div", {
    className: "cui-alert__button"
  }, React.createElement(Button, {
    children: React.createElement(Icon, {
      name: "alarm_16"
    }),
    onClick: onSnooze,
    ariaLabel: "snooze",
    circle: true,
    large: true
  })), React.createElement("div", {
    className: "cui-alert__button"
  }, React.createElement(Button, {
    children: React.createElement(Icon, {
      name: "cancel_16"
    }),
    onClick: onHide,
    ariaLabel: "close",
    circle: true,
    large: true
  })));
};

AlertMeeting.defaultProps = {
  attendees: [],
  title: '',
  status: '',
  message: '',
  onHide: null,
  onSnooze: null,
  avatar: null
};
AlertMeeting.propTypes = {
  /**
   * optional attendee array.  If more than one attendee, a Composite Avatar will be composed.
   * Only use first two attendees in array will be used, the others will be ignored.
   */
  attendees: PropTypes.arrayOf(PropTypes.shape({
    title: PropTypes.string.isRequired,
    alt: PropTypes.string,
    src: PropTypes.string
  })),

  /**
   * optional AlertMeeting Title
   */
  title: PropTypes.string,

  /**
   * optional AlertMeeting Status
   */
  status: PropTypes.string,

  /**
   * optional AlertMeeting Message
   */
  message: PropTypes.string,

  /**
   * show/hide AlertMeeting.
   */
  show: PropTypes.bool.isRequired,

  /**
   * callback function invoked on close of the Alert. Alert can be closed on click of cross button or esc key.
   * onHide is mandatory props, if not passed Alert can not be closed.
   */
  onHide: PropTypes.func,

  /**
   * callback function invoked when the snooze button is clicked.
   */
  onSnooze: PropTypes.func,

  /**
   * optional avatar prop
   */
  avatar: PropTypes.node
};
AlertMeeting.displayName = 'AlertMeeting';
export default AlertMeeting;
/**
* @name Meeting
* @description Control the avatar type by passing in an array of user data in the attendees prop.
*
* @category communication
* @component alert
* @section meeting
*
* @js

import {
  Button,
  AlertMeeting
} from '@collab-ui/react';

export default class Default extends React.PureComponent {
  state = {
    showAlert: false,
    attendees: []
  }

  render() {
    return (
      <section>
        <div>
          <div className='row'>
            <Button
              ariaLabel='Click to Open'
              onClick={() => this.setState({ showAlert: true, attendees: [{title: 'J $'}] })}
              children='Single Attendee'
              color='primary'
              size='large'
            />
          </div>
          <div className='row'>
            <br />
            <Button
              ariaLabel='Click to Open'
              onClick={() => this.setState({ showAlert: true, attendees: [{title: 'J $'}, {title: 'J G'}] })}
              children='Multiple Attendees'
              color='primary'
              size='large'
            />
          </div>
          <br />
          <AlertMeeting
            attendees={this.state.attendees}
            show={this.state.showAlert}
            onHide={() => this.setState({ showAlert: false })}
            title='Super Important Meeting'
            status='In 5 minutes'
            message='This meeting will blow your mind!'
          />
        </div>
      </section>
    );
  }
}

**/

==> react-7.6.0.tgz: package/es/AlertMeeting/index.js <==
import React from 'react';
import PropTypes from 'prop-types';
import { Avatar, CompositeAvatar, Button, Icon } from "./..";
/**
 * @category communication
 * @component meeting-alert
 * @variations collab-ui-react
 */

var AlertMeeting = function AlertMeeting(props) {
  var avatar = props.avatar,
      attendees = props.attendees,
      show = props.show,
      onHide = props.onHide,
      onSnooze = props.onSnooze,
      title = props.title,
      message = props.message,
      status = props.status;

  var renderAvatar = function renderAvatar() {
    if (avatar) {
      return avatar;
    } else {
      if (attendees.length >= 2) {
        return React.createElement(CompositeAvatar, null, React.createElement(Avatar, {
          title: attendees[0].title,
          alt: attendees[0].alt,
          src: attendees[0].src
        }), React.createElement(Avatar, {
          title: attendees[1].title,
          alt: attendees[1].alt,
          src: attendees[1].src
        }));
      } else if (attendees.length === 1) {
        return React.createElement(Avatar, {
          title: attendees[0].title,
          alt: attendees[0].alt,
          src: attendees[0].src
        });
      } else {
        throw new Error('MeetingAlert needs at least one attendee to render an avatar.');
      }
    }
  };

  return show && React.createElement("div", {
    className: "cui-alert cui-alert--meeting"
  }, renderAvatar(), React.createElement("div", {
    className: 'cui-alert__content'
  }, React.createElement("div", {
    className: "cui-alert__title",
    title: title
  }, title), React.createElement("div", {
    className: "cui-alert__status"
  }, status), React.createElement("div", {
    className: "cui-alert__message",
    title: message
  }, message)), React.createElement("div", {
    className: "cui-alert__button"
  }, React.createElement(Button, {
    children: React.createElement(Icon, {
      name: "alarm_16"
    }),
    onClick: onSnooze,
    ariaLabel: "snooze",
    circle: true,
    large: true
  })), React.createElement("div", {
    className: "cui-alert__button"
  }, React.createElement(Button, {
    children: React.createElement(Icon, {
      name: "cancel_16"
    }),
    onClick: onHide,
    ariaLabel: "close",
    circle: true,
    large: true
  })));
};

AlertMeeting.defaultProps = {
  attendees: [],
  title: '',
  status: '',
  message: '',
  onHide: null,
  onSnooze: null,
  avatar: null
};
AlertMeeting.propTypes = {
  /**
   * optional attendee array.  If more than one attendee, a Composite Avatar will be composed.
   * Only use first two attendees in array will be used, the others will be ignored.
   */
  attendees: PropTypes.arrayOf(PropTypes.shape({
    title: PropTypes.string.isRequired,
    alt: PropTypes.string,
    src: PropTypes.string
  })),

  /**
   * optional AlertMeeting Title
   */
  title: PropTypes.string,

  /**
   * optional AlertMeeting Status
   */
  status: PropTypes.string,

  /**
   * optional AlertMeeting Message
   */
  message: PropTypes.string,

  /**
   * show/hide AlertMeeting.
   */
  show: PropTypes.bool.isRequired,

  /**
   * callback function invoked on close of the Alert. Alert can be closed on click of cross button or esc key.
   * onHide is mandatory props, if not passed Alert can not be closed.
   */
  onHide: PropTypes.func,

  /**
   * callback function invoked when the snooze button is clicked.
   */
  onSnooze: PropTypes.func,

  /**
   * optional avatar prop
   */
  avatar: PropTypes.node
};
AlertMeeting.displayName = 'AlertMeeting';
export default AlertMeeting;
/**
* @name Meeting
* @description Control the avatar type by passing in an array of user data in the attendees prop.
*
* @category communication
* @component alert
* @section meeting
*
* @js

import {
  Button,
  AlertMeetingContainer
} from '@collab-ui/react';

export default class Default extends React.PureComponent {

  render() {
    let alertMeetingContainer;
    return (
      <section>
        <div>
          <div className='row'>
            <Button
              ariaLabel='Click to Open'
              onClick={() => alertMeetingContainer.meetingAlert(
                'Important Meeting',
                'In 5 Mins.',
                'This is important',
                () => console.log('onHide meeting1'),
                () => console.log('onSnooze meeting1'),
                [{title: 'J $'}]
              )}
              children='Single Attendee'
              color='primary'
              size='large'
            />
          </div>
          <div className='row'>
            <br />
            <Button
              ariaLabel='Click to Open'
              onClick={() => alertMeetingContainer.meetingAlert(
                'Super Important Meeting',
                'Now',
                'This is super important',
                () => console.log('onHide meeting2'),
                () => console.log('onSnooze meeting2'),
                [{title: 'J $'}, {title: 'J G'}]
              )}
              children='Multiple Attendees'
              color='primary'
              size='large'
            />
          </div>
          <br />
          <AlertMeetingContainer
            ref={ref => alertMeetingContainer = ref}
          />
        </div>
      </section>
    );
  }
}

**/
